@@ -3,10 +3,12 @@ package Module::Build::Notes;
 # A class for persistent hashes
 
 use strict;
+use vars qw($VERSION);
+$VERSION = '0.30_01';
+$VERSION = eval $VERSION;
 use Data::Dumper;
 use IO::File;
-
-use Carp; BEGIN{ $SIG{__DIE__} = \&carp::confess }
+use Module::Build::Dumper;
 
 sub new {
   my ($class, %args) = @_;
@@ -36,7 +38,8 @@ sub access {
   return $self->read($key) unless @_;
   
   my $value = shift;
-  return $self->write({ $key => $value });
+  $self->write({ $key => $value });
+  return $self->read($key);
 }
 
 sub has_data {
@@ -66,6 +69,13 @@ sub read {
   return wantarray ? %$out : $out;
 }
 
+sub _same {
+  my ($self, $x, $y) = @_;
+  return 1 if !defined($x) and !defined($y);
+  return 0 if !defined($x) or  !defined($y);
+  return $x eq $y;
+}
+
 sub write {
   my ($self, $href) = @_;
   $href ||= {};
@@ -76,7 +86,7 @@ sub write {
   foreach my $key (keys %{ $self->{new} }) {
     next if ref $self->{new}{$key};
     next if ref $self->{disk}{$key} or !exists $self->{disk}{$key};
-    delete $self->{new}{$key} if ($self->{new}{$key}||'') eq ($self->{disk}{$key}||'');
+    delete $self->{new}{$key} if $self->_same($self->{new}{$key}, $self->{disk}{$key});
   }
   
   if (my $file = $self->{file}) {
@@ -98,8 +108,7 @@ sub _dump {
   my ($self, $file, $data) = @_;
   
   my $fh = IO::File->new("> $file") or die "Can't create '$file': $!";
-  local $Data::Dumper::Terse = 1;
-  print $fh Data::Dumper::Dumper($data);
+  print {$fh} Module::Build::Dumper->_data_dump($data);
 }
 
 sub write_config_data {
@@ -132,6 +141,9 @@ sub config_names  { keys %%$config }
 sub write {
   my $me = __FILE__;
   require IO::File;
+
+  # Can't use Module::Build::Dumper here because M::B is only a
+  # build-time prereq of this module
   require Data::Dumper;
 
   my $mode_orig = (stat $me)[2] & 07777;
@@ -143,9 +155,11 @@ sub write {
   }
   die "Couldn't find __DATA__ token in $me" if eof($fh);
 
-  local $Data::Dumper::Terse = 1;
   seek($fh, tell($fh), 0);
-  $fh->print( Data::Dumper::Dumper([$config, $features, $auto_features]) );
+  my $data = [$config, $features, $auto_features];
+  $fh->print( 'do{ my '
+	      . Data::Dumper->new([$data],['x'])->Purity(1)->Dump()
+	      . '$x; }' );
   truncate($fh, tell($fh));
   $fh->close;
 
@@ -275,8 +289,7 @@ __DATA__
 
 EOF
 
-  local $Data::Dumper::Terse = 1;
-  print $fh Data::Dumper::Dumper([$args{config_data}, $args{feature}, $args{auto_features}]);
+  print {$fh} Module::Build::Dumper->_data_dump([$args{config_data}, $args{feature}, $args{auto_features}]);
 }
 
 1;
