@@ -1,6 +1,9 @@
 package Module::Build::PPMMaker;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = '0.30_01';
+$VERSION = eval $VERSION;
 
 # This code is mostly borrowed from ExtUtils::MM_Unix 6.10_03, with a
 # few tweaks based on the PPD spec at
@@ -151,14 +154,17 @@ sub _varchname {  # Copied from PPM.pm
 1;
 __END__
 
+
 =head1 NAME
 
 Module::Build::PPMMaker - Perl Package Manager file creation
 
+
 =head1 SYNOPSIS
 
- On the command line, builds a .ppd file:
- % ./Build ppd
+  On the command line, builds a .ppd file:
+  ./Build ppd
+
 
 =head1 DESCRIPTION
 
@@ -167,17 +173,20 @@ Description" files, in support of ActiveState's "Perl Package
 Manager".  Details are here:
 L<http://aspn.activestate.com/ASPN/Downloads/ActivePerl/PPM/>
 
+
 =head1 AUTHOR
 
-Dave Rolsky <autarch@urth.org>, Ken Williams <ken@mathforum.org>
+Dave Rolsky <autarch@urth.org>, Ken Williams <kwilliams@cpan.org>
+
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2005 Ken Williams.  All rights reserved.
+Copyright (c) 2001-2006 Ken Williams.  All rights reserved.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
+
 =head1 SEE ALSO
 
 perl(1), Module::Build(3)
