@@ -1,6 +1,9 @@
 package Module::Build::Platform::aix;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = '0.30_01';
+$VERSION = eval $VERSION;
 use Module::Build::Platform::Unix;
 
 use vars qw(@ISA);
@@ -28,7 +31,7 @@ Please see the L<Module::Build> for the general docs.
 
 =head1 AUTHOR
 
-Ken Williams, ken@mathforum.org
+Ken Williams <kwilliams@cpan.org>
 
 =head1 SEE ALSO
 
