@@ -1,6 +1,9 @@
 package Module::Build::Platform::os2;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = '0.30_01';
+$VERSION = eval $VERSION;
 use Module::Build::Platform::Unix;
 
 use vars qw(@ISA);
@@ -8,7 +11,7 @@ use vars qw(@ISA);
 
 sub manpage_separator { '.' }
 
-sub have_multiarg_pipeopen { 0 }
+sub have_forkpipe { 0 }
 
 1;
 __END__
@@ -27,7 +30,7 @@ Please see the L<Module::Build> for the general docs.
 
 =head1 AUTHOR
 
-Ken Williams <ken@cpan.org>
+Ken Williams <kwilliams@cpan.org>
 
 =head1 SEE ALSO
 
